(function(ns) {
    var _container = $('#trackPanel>#trackContainer'),
        _earth = null,
        _dataProcess = null,
        _seTrackMgr = null,
        _roles = null,
        _trackList = null,
        _tracks = null,
        _trackData = null,
        _trackTree = null,
        _isRealTime = false,
        _isShowRoute = false,
        _modeType = 3,
        _isPlaying = false,
        _curNodeType = '',
        _curNodeLevel = -1,
        _hasChild = false,
        _curTrackType = 0,
        _flyCount = 0;


    //main
    function _initTrack(earth, dataProcess) {
        _earth = earth;
        _dataProcess = dataProcess

        _seTrackMgr = new ns.STAMP.SeTrackManager({
            earth: _earth,
            dataProcess: _dataProcess
        });

        _initUI();
        _addEventListeners();
        _getTrackList();
        _createTrack();
        _createTrackTree();

        _updateState();

        _bindContextMenuEvent();
    }

    function _destroyTrack() {
        _removeEventListeners();
    }

    function _initUI() {
        _initRoles();

        var h = parseFloat($('#trackPanel').css('height'));
        $('#trackPanel>#trackContainer #trackTreeContainer').css('height', (h - 290) + 'px');
    }

    function _addEventListeners() {
        $('#trackPanel>#trackContainer').find('#track').bind('click', function(e) {
            var trackName = '新路径';
            var track = _seTrackMgr.createTrack({
                trackName: trackName
            });
            var tnode = {
                id: track.trackId,
                name: trackName,
                pId: -1,
                isParent: true,
                trackType: 'track'
            };
            _trackTree.addNodes(_trackTree.getNodeByParam("id", -1, null), tnode);

            _tracks.push(track.track);
            _saveTrackList();

            _bindContextMenuEvent();
        });

        $('#trackPanel>#trackContainer').find('#stationPass').bind('click', function(e) {
            var tnode = undefined;
            var routeId = undefined;
            var curNode = _trackTree.getSelectedNodes()[0];
            if (curNode.level == 1) {
                tnode = curNode;
            } else if (curNode.level == 2) {
                routeId = curNode.id;
                tnode = curNode.getParentNode();
            }
            if (!tnode) {
                return;
            }
            var trackId = tnode.id;
            var track = _seTrackMgr.getTrack({
                trackId: trackId
            });
            if (!track) {
                return;
            }

            _earth.Event.OnCreateGeometry = function(pFeat) {
                _earth.Event.OnCreateGeometry = function(pFeat) {};

                _earth.ShapeCreator.Clear();

                if (!pFeat) {
                    return;
                }
                if (pFeat.Count < 3) {
                    alert('路径点不能少于3个');
                    return;
                }

                var result = {
                    routeName: 'pass',
                    flyHeight: 50,
                    flySpeed: 10,
                    routeHeading: 0,
                    routeTilt: 0,
                    routeRate: 0.01
                };

                var route = _seTrackMgr.createRoute({
                    track: track,
                    routeId: routeId,
                    routeName: result.routeName,
                    pos: pFeat,
                    heading: result.routeHeading,
                    tile: result.routeTilt,
                    rate: result.routeRate,
                    params: [{
                        flyHeight: result.flyHeight,
                        flySpeed: result.flySpeed
                    }]
                });
                if (route) {
                    if (curNode.level == 1) {
                        //增加新路径
                        var nodes = [];
                        nodes.push({
                            id: route.Guid,
                            name: route.Name,
                            pId: curNode.id,
                            isParent: false,
                            trackType: 'route'
                        });
                        for (var i = 0, l = route.GetChildCount(); i < l; i++) {
                            var pass = route.GetChildAt(i);
                            nodes.push({
                                id: pass.Guid,
                                name: pass.Name,
                                pId: route.Guid,
                                trackType: 'pass'
                            });
                        }
                        _trackTree.addNodes(curNode, nodes);
                    } else if (curNode.level == 2) {
                        var nodes = [];
                        for (var i = 0, l = route.GetChildCount(); i < l; i++) {
                            var pass = route.GetChildAt(i);
                            nodes.push({
                                id: pass.Guid,
                                name: pass.Name,
                                pId: route.Guid,
                                trackType: 'pass'
                            });
                        }
                        _trackTree.removeChildNodes(curNode);
                        _trackTree.addNodes(curNode, nodes);
                    }
                }

                _seTrackMgr.saveTrackToClient({
                    track: track
                });

                _bindContextMenuEvent();
            }
            _earth.ShapeCreator.CreatePolyline(2, 0xffff0000);
        });

        $('#trackPanel>#trackContainer').find('#stationLookat').bind('click', function(e) {
            var curNode = _trackTree.getSelectedNodes()[0];
            if (curNode.level != 1) {
                return;
            }

            var trackId = curNode.id;
            var track = _seTrackMgr.getTrack({
                trackId: trackId
            });

            _earth.Event.OnCreateGeometry = function(pFeat) {
                _earth.Event.OnCreateGeometry = function(pFeat) {};

                _earth.ShapeCreator.Clear();

                if (!pFeat) {
                    return;
                }

                function fomatFloat(src, pos) {
                    return Math.round(src * Math.pow(10, pos)) / Math.pow(10, pos);
                }

                var position = _earth.GlobeObserver.Pose;
                var result = {
                    name: '观察点',
                    Longitude: pFeat.Longitude,
                    Latitude: pFeat.Latitude,
                    Altitude: pFeat.Altitude,

                    Heading: fomatFloat(position.Heading, 1),
                    Tilt: Math.round(position.Tilt),
                    Roll: fomatFloat(position.Roll, 1),
                    Range: fomatFloat(position.range, 1),
                    StopTime: 5
                };

                var lookat = _seTrackMgr.createLookat({
                    track: track,
                    lookatName: result.name,
                    pos: pFeat,
                    params: result
                });

                if (lookat) {
                    _trackTree.addNodes(curNode, {
                        id: lookat.Guid,
                        name: lookat.Name,
                        pId: curNode.id,
                        trackType: 'lookat'
                    });
                }

                _seTrackMgr.saveTrackToClient({
                    track: track
                });

                _bindContextMenuEvent();
            }
            _earth.ShapeCreator.CreatePoint();
        });

        $('#trackPanel>#trackContainer').find('#stationSurround').bind('click', function(e) {
            var curNode = _trackTree.getSelectedNodes()[0];
            if (curNode.level != 1) {
                return;
            }

            var trackId = curNode.id;
            var track = _seTrackMgr.getTrack({
                trackId: trackId
            });

            _earth.Event.OnCreateGeometry = function(pFeat) {
                _earth.Event.OnCreateGeometry = function(pFeat) {};

                _earth.ShapeCreator.Clear();

                if (!pFeat) {
                    return;
                }

                function fomatFloat(src, pos) {
                    return Math.round(src * Math.pow(10, pos)) / Math.pow(10, pos);
                }

                var result = {
                    name: '环绕点',
                    Longitude: pFeat.Longitude,
                    Latitude: pFeat.Latitude,
                    Altitude: pFeat.Altitude,
                    FlyHeight: 50,
                    Radius: 200,
                    NumberOfCycle: 1,
                    Speed: 10
                };

                var surround = _seTrackMgr.createSurround({
                    track: track,
                    surroundName: result.name,
                    pos: pFeat,
                    params: result
                });

                if (surround) {
                    _trackTree.addNodes(curNode, {
                        id: surround.Guid,
                        name: surround.Name,
                        pId: curNode.id,
                        trackType: 'surround'
                    });
                }

                _seTrackMgr.saveTrackToClient({
                    track: track
                });

                _bindContextMenuEvent();
            }
            _earth.ShapeCreator.CreatePoint();
        });

        $('#trackPanel>#trackContainer').find('#trackPlay').bind('click', function(e) {
            var curNode = _trackTree.getSelectedNodes()[0];
            if (curNode.level != 1) {
                //check the current node
                //only the track node is selected
                //the play btn is available
                return;
            }

            var trackId = curNode.id;
            var track = _seTrackMgr.getTrack({
                trackId: trackId
            });
            if (track) {
                if (track.Status == 0) {
                    var roleId = $('#trackPanel>#trackContainer').find('#roles').val();
                    if (roleId == '') {
                        return;
                    }

                    _seTrackMgr.loadDynamicObject({
                        dynamicId: roleId,
                        onDynamicLoaded: function(options) {
                            var did = options.id;
                            var type = options.type;
                            if (type != 2) {
                                return;
                            }

                            _seTrackMgr.playTrack({
                                track: track,
                                dynamicId: roleId,
                                trackType: _modeType,
                                mode: 2,
                                smooth: false,
                                onTrackFinish: function(options) {
                                    var tid = options.tId;
                                    var did = options.dId;

                                    _seTrackMgr.unloadDynamicObject({
                                        dynamicId: did
                                    });

                                    _flyCount--;
                                    _isPlaying = (_flyCount > 0);
                                    _curTrackType = track.Status;
                                    _updateState();

                                    if (!_isPlaying) {
                                        _seTrackMgr.unbindTrackFinish();
                                    }
                                }
                            });

                            _flyCount++;
                            _isPlaying = (_flyCount > 0);
                            _curTrackType = track.Status;
                            _updateState();
                        }
                    });
                } else if (track.Status == 1) {
                    track.Pause();
                    _curTrackType = track.Status;
                    _updateState();
                } else if (track.Status == 2) {
                    track.Resume();
                    _curTrackType = track.Status;
                    _updateState();
                }
            }
        });

        $('#trackPanel>#trackContainer').find('#trackStop').bind('click', function(e) {
            var curNode = _trackTree.getSelectedNodes()[0];
            if (curNode.level != 1) {
                return;
            }

            var trackId = curNode.id;
            var track = _seTrackMgr.getTrack({
                trackId: trackId
            });

            track.stop();
        });

        $('#trackPanel>#trackContainer').find('#realTime').bind('click', function(e) {
            var chk = $('#trackPanel>#trackContainer').find('#realTime');

            _isRealTime = chk[0].checked;

            var curNode = _trackTree.getSelectedNodes()[0];
            if (curNode.level != 1) {
                return;
            }

            var trackId = curNode.id;
            var track = _seTrackMgr.getTrack({
                trackId: trackId
            });

            if (track) {
                for (var i = 0, l = track.GetChildCount(); i < l; i++) {
                    var station = track.GetChildAt(i);
                    if (station.Rtti == 504) {
                        station.RealtimeMode = _isRealTime;
                    }
                }
            }
        });

        $('#trackPanel>#trackContainer').find('#showRoute').bind('click', function(e) {
            var chk = $('#trackPanel>#trackContainer').find('#showRoute');
            _isShowRoute = chk[0].checked;

            var nodes = [];
            var curNode = _trackTree.getSelectedNodes()[0];
            if (curNode.level == 1) {
                nodes.push(curNode);
            } else if (curNode.level == 0) {
                if (curNode.children) {
                    nodes = curNode.children;
                }
            }

            for (var i = 0; i < nodes.length; i++) {
                var trackId = nodes[i].id;
                var track = _seTrackMgr.getTrack({
                    trackId: trackId
                });

                if (track) {
                    track.Visibility = _isShowRoute;
                }
            }
        });

        $('#trackPanel>#trackContainer').find('#modeType :radio').bind('click', function(e) {
            var rdo = e.currentTarget;

            $('#trackPanel>#trackContainer').find("#modeType :radio").removeAttr("checked");
            $('#trackPanel>#trackContainer').find("#modeType :radio").each(function(i, n) {
                n.checked = false;
            });
            $(rdo).attr("checked", "checked");
            $(rdo)[0].checked = true;
            _modeType = $(rdo).val();

            var curNode = _trackTree.getSelectedNodes()[0];
            if (curNode.level != 1) {
                return;
            }

            var trackId = curNode.id;
            var track = _seTrackMgr.getTrack({
                trackId: trackId
            });

            if (track) {
                track.TrackType = _modeType;
            }
        });

        $(document).bind('keydown', function(e) {
            var curNode = _trackTree.getSelectedNodes()[0];
            if(!curNode){
                return;
            }
            if (curNode.level != 1) {
                return;
            }

            if(!_isPlaying){
                return;
            }

            var trackId = curNode.id;
            var track = _seTrackMgr.getTrack({
                trackId: trackId
            });

            if (e.keyCode == 187 || e.keyCode == 107) {
                //主键盘'+'和数字键盘'+'
                if (_isRealTime) {
                    track.UpdateRate(0);
                    track.CommitChanges();
                }
            } else if (e.keyCode == 189 || e.keyCode == 109) {
                //主键盘'-'和数字键盘'-'
                if (_isRealTime) {
                    track.UpdateRate(1);
                    track.CommitChanges();
                }
            } else {
                if (_isRealTime) {
                    track.UpdateRate(2);
                    track.CommitChanges();
                }
            }
        });
    }

    function _removeEventListeners() {
        $('#trackPanel>#trackContainer').find('#track').unbind('click');
        $('#trackPanel>#trackContainer').find('#stationPass').unbind('click');
        $('#trackPanel>#trackContainer').find('#stationLookat').unbind('click');
        $('#trackPanel>#trackContainer').find('#stationSurround').unbind('click');

        $('#trackPanel>#trackContainer').find('#trackPlay').unbind('click');
        $('#trackPanel>#trackContainer').find('#trackStop').unbind('click');

        $('#trackPanel>#trackContainer').find('#realTime').unbind('click');
        $('#trackPanel>#trackContainer').find('#showRoute').unbind('click');
        $('#trackPanel>#trackContainer').find('#modeType :radio').unbind('click');

        $(document).unbind('keydown');
    }

    function _initRoles() {
        _roles = [];
        _seTrackMgr.getDynamicObject({
            onFlyObject: function(flyRole) {
                if (flyRole) {
                    _roles.push({
                        id: flyRole.Guid,
                        name: flyRole.Name
                    });
                }
            },
            onDynamicListLoaded: function(roles) {
                var ops = '';
                for (var i = 0, l = _roles.length; i < l; i++) {
                    ops += '<option value="' + _roles[i].id + '">' + _roles[i].name + '</option>';
                }
                $('#trackPanel>#trackContainer').find('#roles').html(ops);
                $('#trackPanel>#trackContainer').find('#roles').selectpicker();
            }
        });
    }

    function _getTrackList() {
        if (_trackList) {
            if ($.isArray(_trackList)) {
                _trackList.splice(0, _trackList.length);
            }
            _trackList = null;
        }
        _trackList = _seTrackMgr.getTrackListFromClient();
    }

    function _saveTrackList() {
        _seTrackMgr.saveTrackListToClient({
            tracks: _tracks
        });
    }

    function _createTrack() {
        _clearTracks();

        _tracks = [];
        if (_trackList && _trackList.length > 0) {
            for (var i = 0; i < _trackList.length; i++) {
                var track = _seTrackMgr.createTrackFromClient({
                    trackId: _trackList[i].id,
                    trackName: _trackList[i].name
                });

                _tracks.push(track);
            }
        }
    }

    function _clearTracks() {
        _seTrackMgr.clearTrack({
            mode: 1
        });

        if (_tracks) {
            if ($.isArray(_tracks)) {
                _tracks.splice(0, _tracks.length);
            }
            _tracks = null;
        }

        if (_trackData) {
            if ($.isArray(_trackData)) {
                _trackData.splice(0, _trackData.length);
            }
            _trackData = null;
        }

        _trackTree = null;
    }

    function _createTrackTree() {
        var trackTreeData = [{
            id: -1,
            name: '路径',
            open: true,
            isParent: true,
            trackType: 'root'
        }];

        $.each(_tracks, function(i, track) {
            trackTreeData.push({
                id: track.Guid,
                pId: -1,
                name: track.Name,
                isParent: true,
                trackType: 'track'
            });

            for (var i = 0, l = track.GetChildCount(); i < l; i++) {
                var st = track.GetChildAt(i);
                var tt = '';
                switch (st.Rtti) {
                    case 504:
                        tt = 'route';
                        break;
                    case 503:
                        tt = 'surround';
                        break;
                    case 502:
                        tt = 'lookat';
                        break;
                    case 501:
                        tt = 'pass';
                        break;
                }
                trackTreeData.push({
                    id: st.Guid,
                    name: st.Name,
                    pId: track.Guid,
                    trackType: tt
                });

                if (st.Rtti == 504) {
                    //StationRoute
                    for (var j = 0, m = st.GetChildCount(); j < m; j++) {
                        var pass = st.GetChildAt(j);
                        trackTreeData.push({
                            id: pass.Guid,
                            name: pass.Name,
                            pId: st.Guid,
                            trackType: 'pass'
                        });
                    }
                }
            }
        });

        if (_trackData) {
            if ($.isArray(_trackData)) {
                _trackData.splice(0, _trackData.length);
            }
            _trackData = null;
        }
        _trackData = trackTreeData;

        var setting = {
            data: {
                simpleData: {
                    enable: true
                },
                keep: {
                    parent: true
                }
            },
            edit: {
                enable: true,
                showRemoveBtn: false,
                showRenameBtn: false,
                drag: {
                    prev: false,
                    inner: false,
                    next: false,
                    isMove: false,
                    isCopy: false
                }
            },
            view: {
                autoCancelSelected: false,
                selectedMulti: false,
                showTitle: false,
                addDiyDom: function(treeId, treeNode) {
                    if (treeNode.trackType != 'root') {
                        $("#" + treeNode.tId + "_a").attr('data-toggle', 'context')
                            .attr('data-target', '#context-menu');
                    }
                }
            },
            callback: {
                onClick: function(event, treeId, node) {
                    if (!node) {
                        return;
                    }

                    _isRealTime = false;
                    _isShowRoute = false;
                    _modeType = 3;
                    _curNodeType = node.trackType;
                    _curNodeLevel = node.level;
                    _hasChild = false;
                    _curTrackType = 0;

                    var tnode = undefined;
                    if (node.level == 0) {

                    } else if (node.level == 1) {
                        tnode = node;
                    } else {
                        while (node.level > 1) {
                            node = node.getParentNode();
                        }
                        tnode = node;
                    }

                    if (tnode) {
                        if (tnode.children && tnode.children.length > 0) {
                            _hasChild = true;
                        }

                        var track = _seTrackMgr.getTrack({
                            trackId: tnode.id
                        });

                        if (track) {
                            _isShowRoute = track.Visibility;
                            _modeType = track.TrackType;
                            _curTrackType = track.Status;

                            if (track.Status == 1 || track.Status == 2) {
                                $('#trackPanel>#trackContainer').find("#roles").val(track.BindObject);
                                _earth.TrackControl.SetMainTrack(track.Guid, 0);
                            }

                            for (var i = 0, l = track.GetChildCount(); i < l; i++) {
                                var station = track.GetChildAt(i);
                                if (station.Rtti == 504) {
                                    _isRealTime = station.RealtimeMode;
                                    break;
                                }
                            }
                        }
                    }

                    _updateState();
                },
                onExpand: function(event, treeId, treeNode) {
                    _bindContextMenuEvent();
                }
            }
        };

        _trackTree = $.fn.zTree.init($('#trackPanel>#trackContainer').find("#trackTree"), setting, trackTreeData);
    }

    function _updateState() {
        //checked attr
        if (_isRealTime) {
            $('#trackPanel>#trackContainer').find('#realTime').attr('checked', 'checked');
            $('#trackPanel>#trackContainer').find('#realTime')[0].checked = true;
        } else {
            $('#trackPanel>#trackContainer').find('#realTime').removeAttr('checked');
            $('#trackPanel>#trackContainer').find('#realTime')[0].checked = false;
        }

        if (_isShowRoute) {
            $('#trackPanel>#trackContainer').find('#showRoute').attr('checked', 'checked');
            $('#trackPanel>#trackContainer').find('#showRoute')[0].checked = true;
        } else {
            $('#trackPanel>#trackContainer').find('#showRoute').removeAttr('checked');
            $('#trackPanel>#trackContainer').find('#showRoute')[0].checked = false;
        }

        if (_modeType == 1) {
            $('#trackPanel>#trackContainer').find('#modeType :radio:eq(0)').attr('checked', 'checked');
            $('#trackPanel>#trackContainer').find('#modeType :radio')[0].checked = true;
            $('#trackPanel>#trackContainer').find('#modeType :radio:eq(1)').removeAttr('checked');
            $('#trackPanel>#trackContainer').find('#modeType :radio')[1].checked = false;
        } else {
            $('#trackPanel>#trackContainer').find('#modeType :radio:eq(0)').removeAttr('checked');
            $('#trackPanel>#trackContainer').find('#modeType :radio')[0].checked = false;
            $('#trackPanel>#trackContainer').find('#modeType :radio:eq(1)').attr('checked', 'checked');
            $('#trackPanel>#trackContainer').find('#modeType :radio')[1].checked = true;
        }

        //disabled attr
        function enableNewBtn(enable, index) {
            var btn = $('#trackPanel>#trackContainer').find('#newBtns button').eq(index);
            if (enable) {
                btn.removeAttr('disabled');
            } else {
                btn.attr('disabled', 'disabled');
            }
        }

        function enableNewBtns(flag) {
            //flag 0,1,2,3位分别表示四个按钮是否启用
            for (var i = 0; i < 4; i++) {
                var t = Math.pow(2, i);
                enableNewBtn(((flag & t) == t), i);
            }
        }

        if (_curNodeLevel == 0 || _curNodeLevel == 1) {
            $('#trackPanel>#trackContainer').find('#showRoute').removeAttr('disabled');
            $('#trackPanel>#trackContainer').find('#lblShowRoute').removeAttr('disabled');
        } else {
            $('#trackPanel>#trackContainer').find('#showRoute').attr('disabled', 'disabled');
            $('#trackPanel>#trackContainer').find('#lblShowRoute').attr('disabled', 'disabled');
        }

        if (_isPlaying) {
            enableNewBtns(0);

            $('#trackPanel>#trackContainer').find('#trackPlay').attr('disabled', 'disabled');
            $('#trackPanel>#trackContainer').find('#trackPlay').text('飞行');
            $('#trackPanel>#trackContainer').find('#trackPlay').removeClass('btn-danger').addClass('btn-success');
            $('#trackPanel>#trackContainer').find('#trackStop').attr('disabled', 'disabled');
            $('#trackPanel>#trackContainer').find('#realTime').attr('disabled', 'disabled');
            $('#trackPanel>#trackContainer').find('#lblRealTime').attr('disabled', 'disabled');
            $('#trackPanel>#trackContainer').find('#modeType').attr('disabled', 'disabled');
            if (_curNodeType == 'root' && _curNodeLevel == 0) {

            } else if (_curNodeType == 'track' && _curNodeLevel == 1) {
                $('#trackPanel>#trackContainer').find('#trackPlay').removeAttr('disabled');
                $('#trackPanel>#trackContainer').find('#trackStop').removeAttr('disabled');
                $('#trackPanel>#trackContainer').find('#realTime').removeAttr('disabled');
                $('#trackPanel>#trackContainer').find('#lblRealTime').removeAttr('disabled');
                $('#trackPanel>#trackContainer').find('#modeType').removeAttr('disabled');
                if (_curTrackType == 1) {
                    $('#trackPanel>#trackContainer').find('#trackPlay').text('暂停');
                    $('#trackPanel>#trackContainer').find('#trackPlay').removeClass('btn-success').addClass('btn-danger');
                } else if (_curTrackType == 2) {
                    $('#trackPanel>#trackContainer').find('#trackPlay').text('继续');
                    $('#trackPanel>#trackContainer').find('#trackPlay').removeClass('btn-danger').addClass('btn-success');
                } else {
                    $('#trackPanel>#trackContainer').find('#trackPlay').text('飞行');
                    $('#trackPanel>#trackContainer').find('#trackPlay').removeClass('btn-danger').addClass('btn-success');
                }
            } else if (_curNodeLevel == 2) {

            } else if (_curNodeType == 'pass' && _curNodeLevel == 3) {

            } else {

            }
        } else {
            if (_curNodeType == 'root' && _curNodeLevel == 0) {
                enableNewBtns(1);
                $('#trackPanel>#trackContainer').find('#trackPlay').attr('disabled', 'disabled');
            } else if (_curNodeType == 'track' && _curNodeLevel == 1) {
                enableNewBtns(15);
                if (_hasChild) {
                    $('#trackPanel>#trackContainer').find('#trackPlay').removeAttr('disabled');
                } else {
                    $('#trackPanel>#trackContainer').find('#trackPlay').attr('disabled', 'disabled');
                }
            } else if (_curNodeLevel == 2) {
                if (_curNodeType == 'route') {
                    enableNewBtns(3);
                } else {
                    enableNewBtns(1);
                }
                $('#trackPanel>#trackContainer').find('#trackPlay').attr('disabled', 'disabled');
            } else if (_curNodeType == 'pass' && _curNodeLevel == 3) {
                enableNewBtns(1);
                $('#trackPanel>#trackContainer').find('#trackPlay').attr('disabled', 'disabled');
            } else {
                enableNewBtns(1);
                $('#trackPanel>#trackContainer').find('#trackPlay').attr('disabled', 'disabled');
            }

            $('#trackPanel>#trackContainer').find('#trackPlay').text('飞行');
            $('#trackPanel>#trackContainer').find('#trackPlay').removeClass('btn-danger').addClass('btn-success');
            $('#trackPanel>#trackContainer').find('#trackStop').attr('disabled', 'disabled');

            $('#trackPanel>#trackContainer').find('#realTime').attr('disabled', 'disabled');
            $('#trackPanel>#trackContainer').find('#lblRealTime').attr('disabled', 'disabled');

            $('#trackPanel>#trackContainer').find('#modeType').attr('disabled', 'disabled');
        }
    }

    function _bindContextMenuEvent() {
        $('#trackPanel>#trackContainer').find('#trackTree a[data-toggle="context"]').contextmenu({
            onItem: function(context, e) {
                var menu = e.target.id;
                switch (menu) {
                    case 'att':
                        break;
                    case 'del':
                        var curNode = _trackTree.getSelectedNodes()[0]
                        if (curNode.level == 1) {
                            var tracks = _tracks;
                            for (var i = 0; i < tracks.length; i++) {
                                if (tracks[i].Guid == curNode.id) {
                                    tracks.splice(i, 1);
                                    break;
                                }
                            }
                            _seTrackMgr.deleteTrack({
                                trackId: curNode.id
                            });
                            _seTrackMgr.saveTrackListToClient({
                                tracks: tracks
                            });
                            _seTrackMgr.deleteTrackFromClient({
                                trackId: curNode.id
                            })
                        } else if (curNode.level > 1) {
                            var trackId = null;
                            if (curNode.level == 3) {
                                trackId = curNode.getParentNode().getParentNode().id;
                            } else {
                                trackId = curNode.getParentNode().id;
                            }
                            var track = _seTrackMgr.getTrack({
                                trackId: trackId
                            });
                            track.DeleteStation(curNode.id);
                            track.CommitChanges();

                            _seTrackMgr.saveTrackToClient({
                                track: track
                            });
                        }
                        _trackTree.removeNode(curNode);
                        break;
                }
            },
            before: function(e, context) {
                if (_isPlaying) {
                    return false;
                }

                var eid = e.target.id;
                _trackTree.selectNode(_trackTree.getNodeByParam('tId', 'trackTree_' + eid.split('_')[1], null));

                //trigger a click event to update ui state
                $(e.target).trigger('click');

                return true;
            }
        });
    }



    if (!ns.STAMP.initer) {
        ns.STAMP.initer = {};
    }
    ns.STAMP.initer.initTrack = _initTrack;
    ns.STAMP.initer.destroyTrack = _destroyTrack;
})(window);
